Class: Aws::SocialMessaging::Types::AssociateWhatsAppBusinessAccountOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::AssociateWhatsAppBusinessAccountOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#linked_whats_app_business_account_id ⇒ String
The ID of the WhatsApp Business Account that was linked to your Amazon Web Services account.
-
#signup_callback_result ⇒ Types::WhatsAppSignupCallbackResult
Contains your WhatsApp registration status.
-
#status_code ⇒ Integer
The status code for the response.
Instance Attribute Details
#linked_whats_app_business_account_id ⇒ String
The ID of the WhatsApp Business Account that was linked to your Amazon Web Services account.
72 73 74 75 76 77 78 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 72 class AssociateWhatsAppBusinessAccountOutput < Struct.new( :signup_callback_result, :status_code, :linked_whats_app_business_account_id) SENSITIVE = [] include Aws::Structure end |
#signup_callback_result ⇒ Types::WhatsAppSignupCallbackResult
Contains your WhatsApp registration status.
72 73 74 75 76 77 78 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 72 class AssociateWhatsAppBusinessAccountOutput < Struct.new( :signup_callback_result, :status_code, :linked_whats_app_business_account_id) SENSITIVE = [] include Aws::Structure end |
#status_code ⇒ Integer
The status code for the response.
72 73 74 75 76 77 78 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 72 class AssociateWhatsAppBusinessAccountOutput < Struct.new( :signup_callback_result, :status_code, :linked_whats_app_business_account_id) SENSITIVE = [] include Aws::Structure end |