Class: Aws::SocialMessaging::Types::CreateWhatsAppFlowInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-socialmessaging/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#categoriesArray<String>

The categories that classify the business purpose of the Flow. At least one category is required.

Returns:

  • (Array<String>)


111
112
113
114
115
116
117
118
119
120
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111

class CreateWhatsAppFlowInput < Struct.new(
  :id,
  :flow_name,
  :categories,
  :flow_json,
  :publish,
  :clone_flow_id)
  SENSITIVE = []
  include Aws::Structure
end

#clone_flow_idString

The ID of an existing Flow within the same WhatsApp Business Account to clone.

Returns:

  • (String)


111
112
113
114
115
116
117
118
119
120
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111

class CreateWhatsAppFlowInput < Struct.new(
  :id,
  :flow_name,
  :categories,
  :flow_json,
  :publish,
  :clone_flow_id)
  SENSITIVE = []
  include Aws::Structure
end

#flow_jsonString

The Flow JSON definition that describes the screens, components, and logic of the Flow. Maximum size is 10 MB.

Returns:

  • (String)


111
112
113
114
115
116
117
118
119
120
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111

class CreateWhatsAppFlowInput < Struct.new(
  :id,
  :flow_name,
  :categories,
  :flow_json,
  :publish,
  :clone_flow_id)
  SENSITIVE = []
  include Aws::Structure
end

#flow_nameString

The name of the Flow. Must be unique within the WhatsApp Business Account.

Returns:

  • (String)


111
112
113
114
115
116
117
118
119
120
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111

class CreateWhatsAppFlowInput < Struct.new(
  :id,
  :flow_name,
  :categories,
  :flow_json,
  :publish,
  :clone_flow_id)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the WhatsApp Business Account to associate with this Flow.

Returns:

  • (String)


111
112
113
114
115
116
117
118
119
120
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111

class CreateWhatsAppFlowInput < Struct.new(
  :id,
  :flow_name,
  :categories,
  :flow_json,
  :publish,
  :clone_flow_id)
  SENSITIVE = []
  include Aws::Structure
end

#publishBoolean

Set to ‘true` to publish the Flow immediately after creation. Requires a valid `flowJson` that passes Meta’s validation.

Returns:

  • (Boolean)


111
112
113
114
115
116
117
118
119
120
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111

class CreateWhatsAppFlowInput < Struct.new(
  :id,
  :flow_name,
  :categories,
  :flow_json,
  :publish,
  :clone_flow_id)
  SENSITIVE = []
  include Aws::Structure
end