Class: Aws::SocialMessaging::Types::CreateWhatsAppMessageTemplateOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::CreateWhatsAppMessageTemplateOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The category of the template, such as UTILITY or MARKETING.
-
#meta_template_id ⇒ String
The numeric ID assigned to the template by Meta.
-
#template_status ⇒ String
The status of the created template, such as PENDING or APPROVED..
Instance Attribute Details
#category ⇒ String
The category of the template, such as UTILITY or MARKETING.
185 186 187 188 189 190 191 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 185 class CreateWhatsAppMessageTemplateOutput < Struct.new( :meta_template_id, :template_status, :category) SENSITIVE = [] include Aws::Structure end |
#meta_template_id ⇒ String
The numeric ID assigned to the template by Meta.
185 186 187 188 189 190 191 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 185 class CreateWhatsAppMessageTemplateOutput < Struct.new( :meta_template_id, :template_status, :category) SENSITIVE = [] include Aws::Structure end |
#template_status ⇒ String
The status of the created template, such as PENDING or APPROVED..
185 186 187 188 189 190 191 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 185 class CreateWhatsAppMessageTemplateOutput < Struct.new( :meta_template_id, :template_status, :category) SENSITIVE = [] include Aws::Structure end |