Class: Aws::SocialMessaging::Types::MetaFlowSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::MetaFlowSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Contains summary information about a WhatsApp Flow, including its ID, name, status, and categories.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_categories ⇒ Array<String>
The categories that classify the business purpose of the Flow.
-
#flow_id ⇒ String
The unique identifier of the Flow assigned by Meta.
-
#flow_name ⇒ String
The name of the Flow.
-
#flow_status ⇒ String
The lifecycle status of the Flow (DRAFT, PUBLISHED, DEPRECATED, BLOCKED, or THROTTLED).
-
#validation_errors ⇒ Array<String>
A list of validation errors from Meta, if any.
Instance Attribute Details
#flow_categories ⇒ Array<String>
The categories that classify the business purpose of the Flow.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1382 class MetaFlowSummary < Struct.new( :flow_id, :flow_name, :flow_status, :flow_categories, :validation_errors) SENSITIVE = [] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the Flow assigned by Meta.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1382 class MetaFlowSummary < Struct.new( :flow_id, :flow_name, :flow_status, :flow_categories, :validation_errors) SENSITIVE = [] include Aws::Structure end |
#flow_name ⇒ String
The name of the Flow.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1382 class MetaFlowSummary < Struct.new( :flow_id, :flow_name, :flow_status, :flow_categories, :validation_errors) SENSITIVE = [] include Aws::Structure end |
#flow_status ⇒ String
The lifecycle status of the Flow (DRAFT, PUBLISHED, DEPRECATED, BLOCKED, or THROTTLED).
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1382 class MetaFlowSummary < Struct.new( :flow_id, :flow_name, :flow_status, :flow_categories, :validation_errors) SENSITIVE = [] include Aws::Structure end |
#validation_errors ⇒ Array<String>
A list of validation errors from Meta, if any.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1382 class MetaFlowSummary < Struct.new( :flow_id, :flow_name, :flow_status, :flow_categories, :validation_errors) SENSITIVE = [] include Aws::Structure end |