Class: Aws::SocialMessaging::Types::S3File

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-socialmessaging/types.rb

Overview

Contains information for the S3 bucket that contains media files.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_nameString

The bucket name.

Returns:

  • (String)


1659
1660
1661
1662
1663
1664
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1659

class S3File < Struct.new(
  :bucket_name,
  :key)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The S3 key prefix that defines the storage location of your media files. The prefix works like a folder path in S3, and is combined with the WhatsApp mediaId to create the final file path.

For example, if a media file’s WhatsApp mediaId is ‘123.ogg`, and the key is `audio/example.ogg`, the final file path is `audio/example.ogg123.ogg`.

For the same mediaId, a key of ‘audio/` results in the file path `audio/123.ogg`.

Returns:

  • (String)


1659
1660
1661
1662
1663
1664
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1659

class S3File < Struct.new(
  :bucket_name,
  :key)
  SENSITIVE = []
  include Aws::Structure
end