Class: Aws::SocialMessaging::Types::TemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::TemplateSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Provides a summary of a WhatsApp message template's key attributes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#meta_template_id ⇒ String
The numeric ID assigned to the template by Meta.
-
#template_category ⇒ String
The category of the template (for example, UTILITY or MARKETING).
-
#template_language ⇒ String
The language code of the template (for example, en_US).
-
#template_name ⇒ String
The name of the template.
-
#template_quality_score ⇒ String
The quality score assigned to the template by Meta.
-
#template_status ⇒ String
The current status of the template (for example, APPROVED, PENDING, or REJECTED).
Instance Attribute Details
#meta_template_id ⇒ String
The numeric ID assigned to the template by Meta.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1912 class TemplateSummary < Struct.new( :template_name, :meta_template_id, :template_status, :template_quality_score, :template_language, :template_category) SENSITIVE = [] include Aws::Structure end |
#template_category ⇒ String
The category of the template (for example, UTILITY or MARKETING).
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1912 class TemplateSummary < Struct.new( :template_name, :meta_template_id, :template_status, :template_quality_score, :template_language, :template_category) SENSITIVE = [] include Aws::Structure end |
#template_language ⇒ String
The language code of the template (for example, en_US).
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1912 class TemplateSummary < Struct.new( :template_name, :meta_template_id, :template_status, :template_quality_score, :template_language, :template_category) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the template.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1912 class TemplateSummary < Struct.new( :template_name, :meta_template_id, :template_status, :template_quality_score, :template_language, :template_category) SENSITIVE = [] include Aws::Structure end |
#template_quality_score ⇒ String
The quality score assigned to the template by Meta.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1912 class TemplateSummary < Struct.new( :template_name, :meta_template_id, :template_status, :template_quality_score, :template_language, :template_category) SENSITIVE = [] include Aws::Structure end |
#template_status ⇒ String
The current status of the template (for example, APPROVED, PENDING, or REJECTED).
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1912 class TemplateSummary < Struct.new( :template_name, :meta_template_id, :template_status, :template_quality_score, :template_language, :template_category) SENSITIVE = [] include Aws::Structure end |