Class: Aws::SocialMessaging::Types::UpdateWhatsAppFlowAssetsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::UpdateWhatsAppFlowAssetsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_id ⇒ String
The unique identifier of the Flow whose assets to update.
-
#flow_json ⇒ String
The updated Flow JSON definition.
-
#id ⇒ String
The ID of the WhatsApp Business Account associated with this Flow.
Instance Attribute Details
#flow_id ⇒ String
The unique identifier of the Flow whose assets to update.
1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1898 class UpdateWhatsAppFlowAssetsInput < Struct.new( :id, :flow_id, :flow_json) SENSITIVE = [] include Aws::Structure end |
#flow_json ⇒ String
The updated Flow JSON definition. Maximum size is 10 MB.
1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1898 class UpdateWhatsAppFlowAssetsInput < Struct.new( :id, :flow_id, :flow_json) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the WhatsApp Business Account associated with this Flow.
1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1898 class UpdateWhatsAppFlowAssetsInput < Struct.new( :id, :flow_id, :flow_json) SENSITIVE = [] include Aws::Structure end |