Class: Aws::SocialMessaging::Types::UpdateWhatsAppFlowAssetsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-socialmessaging/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#validation_errorsArray<String>

A list of validation errors returned by Meta, if any. Validation errors must be resolved before the Flow can be published.

Returns:

  • (Array<String>)


1994
1995
1996
1997
1998
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1994

class UpdateWhatsAppFlowAssetsOutput < Struct.new(
  :validation_errors)
  SENSITIVE = []
  include Aws::Structure
end