Class: Aws::SocialMessaging::Types::WabaPhoneNumberSetupFinalization
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::WabaPhoneNumberSetupFinalization
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
The registration details for a linked phone number.
Constant Summary collapse
- SENSITIVE =
[:two_factor_pin]
Instance Attribute Summary collapse
-
#data_localization_region ⇒ String
The two letter ISO region for the location of where Meta will store data.
-
#id ⇒ String
The unique identifier of the originating phone number associated with the media.
-
#tags ⇒ Array<Types::Tag>
An array of key and value pair tags.
-
#two_factor_pin ⇒ String
The PIN to use for two-step verification.
Instance Attribute Details
#data_localization_region ⇒ String
The two letter ISO region for the location of where Meta will store data.
Asia–Pacific (APAC)
-
Australia AU
-
Indonesia ID
-
India IN
-
Japan JP
-
Singapore SG
-
South Korea KR
Europe
-
Germany DE
-
Switzerland CH
-
United Kingdom GB
Latin America (LATAM)
- Brazil BR
^
Middle East and Africa (MEA)
-
Bahrain BH
-
South Africa ZA
-
United Arab Emirates AE
North America (NORAM)
- Canada CA
^
2100 2101 2102 2103 2104 2105 2106 2107 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 2100 class WabaPhoneNumberSetupFinalization < Struct.new( :id, :two_factor_pin, :data_localization_region, :tags) SENSITIVE = [:two_factor_pin] include Aws::Structure end |
#id ⇒ String
The unique identifier of the originating phone number associated
with the media. Phone number identifiers are formatted as
phone-number-id-01234567890123456789012345678901. Use the
GetLinkedWhatsAppBusinessAccount API action to find a phone
number's id.
2100 2101 2102 2103 2104 2105 2106 2107 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 2100 class WabaPhoneNumberSetupFinalization < Struct.new( :id, :two_factor_pin, :data_localization_region, :tags) SENSITIVE = [:two_factor_pin] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key and value pair tags.
2100 2101 2102 2103 2104 2105 2106 2107 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 2100 class WabaPhoneNumberSetupFinalization < Struct.new( :id, :two_factor_pin, :data_localization_region, :tags) SENSITIVE = [:two_factor_pin] include Aws::Structure end |
#two_factor_pin ⇒ String
The PIN to use for two-step verification. To reset your PIN follow the directions in Updating PIN in the WhatsApp Business Platform Cloud API Reference.
2100 2101 2102 2103 2104 2105 2106 2107 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 2100 class WabaPhoneNumberSetupFinalization < Struct.new( :id, :two_factor_pin, :data_localization_region, :tags) SENSITIVE = [:two_factor_pin] include Aws::Structure end |