Class: Aws::SocialMessaging::Types::WhatsAppBusinessAccountEventDestination
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::WhatsAppBusinessAccountEventDestination
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Contains information on the event destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_destination_arn ⇒ String
The ARN of the event destination.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an Identity and Access Management role that is able to import phone numbers and write events.
Instance Attribute Details
#event_destination_arn ⇒ String
The ARN of the event destination.
2147 2148 2149 2150 2151 2152 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 2147 class WhatsAppBusinessAccountEventDestination < Struct.new( :event_destination_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an Identity and Access Management role that is able to import phone numbers and write events.
2147 2148 2149 2150 2151 2152 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 2147 class WhatsAppBusinessAccountEventDestination < Struct.new( :event_destination_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |