Class: Aws::SocialMessaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SocialMessaging::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-socialmessaging/client.rb,
sig/client.rbs
Overview
An API client for SocialMessaging. To construct a client, you need to configure a :region and :credentials.
client = Aws::SocialMessaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateWhatsAppBusinessAccountResponseSuccess, _CreateWhatsAppFlowResponseSuccess, _CreateWhatsAppMessageTemplateFromLibraryResponseSuccess, _CreateWhatsAppMessageTemplateMediaResponseSuccess, _CreateWhatsAppMessageTemplateResponseSuccess, _DeleteWhatsAppFlowResponseSuccess, _DeleteWhatsAppMessageMediaResponseSuccess, _DeleteWhatsAppMessageTemplateResponseSuccess, _DeprecateWhatsAppFlowResponseSuccess, _DisassociateWhatsAppBusinessAccountResponseSuccess, _GetLinkedWhatsAppBusinessAccountPhoneNumberResponseSuccess, _GetLinkedWhatsAppBusinessAccountResponseSuccess, _GetWhatsAppFlowPreviewResponseSuccess, _GetWhatsAppFlowResponseSuccess, _GetWhatsAppMessageMediaResponseSuccess, _GetWhatsAppMessageTemplateResponseSuccess, _ListLinkedWhatsAppBusinessAccountsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWhatsAppFlowAssetsResponseSuccess, _ListWhatsAppFlowsResponseSuccess, _ListWhatsAppMessageTemplatesResponseSuccess, _ListWhatsAppTemplateLibraryResponseSuccess, _PostWhatsAppMessageMediaResponseSuccess, _PublishWhatsAppFlowResponseSuccess, _PutWhatsAppBusinessAccountEventDestinationsResponseSuccess, _SendWhatsAppMessageResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateWhatsAppFlowAssetsResponseSuccess, _UpdateWhatsAppFlowResponseSuccess, _UpdateWhatsAppMessageTemplateResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
-
#create_whats_app_flow(params = {}) ⇒ Types::CreateWhatsAppFlowOutput
Creates a new WhatsApp Flow.
-
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
-
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta's template library.
-
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
-
#delete_whats_app_flow(params = {}) ⇒ Struct
Deletes a WhatsApp Flow permanently.
-
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service.
-
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
-
#deprecate_whats_app_flow(params = {}) ⇒ Struct
Deprecates a published WhatsApp Flow, marking it as no longer recommended for use.
-
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
-
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
-
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
-
#get_whats_app_flow(params = {}) ⇒ Types::GetWhatsAppFlowOutput
Retrieves the metadata and status of a WhatsApp Flow, including validation errors, preview information, and health status.
-
#get_whats_app_flow_preview(params = {}) ⇒ Types::GetWhatsAppFlowPreviewOutput
Generates a web preview URL for testing a WhatsApp Flow before publishing.
-
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service.
-
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
-
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
-
#list_whats_app_flow_assets(params = {}) ⇒ Types::ListWhatsAppFlowAssetsOutput
Lists the assets (Flow JSON definition) of a WhatsApp Flow with presigned download URLs.
-
#list_whats_app_flows(params = {}) ⇒ Types::ListWhatsAppFlowsOutput
Lists all WhatsApp Flows for a WhatsApp Business Account.
-
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
-
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta's template library for WhatsApp messaging.
-
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service.
-
#publish_whats_app_flow(params = {}) ⇒ Struct
Publishes a WhatsApp Flow, making it available for use in template messages.
-
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA).
-
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message.
-
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource.
-
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
-
#update_whats_app_flow(params = {}) ⇒ Struct
Updates the metadata of a WhatsApp Flow, such as its name or categories.
-
#update_whats_app_flow_assets(params = {}) ⇒ Types::UpdateWhatsAppFlowAssetsOutput
Updates the Flow JSON definition (assets) of a WhatsApp Flow.
-
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1976 1977 1978 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1976 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1979 1980 1981 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1979 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
88 |
# File 'sig/client.rbs', line 88
def associate_whats_app_business_account: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1949 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SocialMessaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-socialmessaging' context[:gem_version] = '1.28.0' Seahorse::Client::Request.new(handlers, context) end |
#create_whats_app_flow(params = {}) ⇒ Types::CreateWhatsAppFlowOutput
Creates a new WhatsApp Flow. Flows enable businesses to create rich,
interactive forms and experiences that users can complete without
leaving WhatsApp. The Flow is created in DRAFT status. If publish is
set to true and a valid flowJson is provided, the Flow is
published immediately.
134 |
# File 'sig/client.rbs', line 134
def create_whats_app_flow: (
|
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
151 |
# File 'sig/client.rbs', line 151
def create_whats_app_message_template: (
|
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta's template library.
164 |
# File 'sig/client.rbs', line 164
def create_whats_app_message_template_from_library: (
|
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
199 |
# File 'sig/client.rbs', line 199
def create_whats_app_message_template_media: (
|
#delete_whats_app_flow(params = {}) ⇒ Struct
Deletes a WhatsApp Flow permanently. Only Flows in DRAFT status can be deleted. Published or deprecated Flows cannot be deleted.
212 |
# File 'sig/client.rbs', line 212
def delete_whats_app_flow: (
|
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service. If the object is still in an Amazon S3 bucket you should delete it from there too.
223 |
# File 'sig/client.rbs', line 223
def delete_whats_app_message_media: (
|
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
233 |
# File 'sig/client.rbs', line 233
def delete_whats_app_message_template: (
|
#deprecate_whats_app_flow(params = {}) ⇒ Struct
Deprecates a published WhatsApp Flow, marking it as no longer recommended for use. The Flow must be in PUBLISHED status. This is an irreversible operation.
245 |
# File 'sig/client.rbs', line 245
def deprecate_whats_app_flow: (
|
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
255 |
# File 'sig/client.rbs', line 255
def disassociate_whats_app_business_account: (
|
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
265 |
# File 'sig/client.rbs', line 265
def get_linked_whats_app_business_account: (
|
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
276 |
# File 'sig/client.rbs', line 276
def get_linked_whats_app_business_account_phone_number: (
|
#get_whats_app_flow(params = {}) ⇒ Types::GetWhatsAppFlowOutput
Retrieves the metadata and status of a WhatsApp Flow, including validation errors, preview information, and health status.
297 |
# File 'sig/client.rbs', line 297
def get_whats_app_flow: (
|
#get_whats_app_flow_preview(params = {}) ⇒ Types::GetWhatsAppFlowPreviewOutput
Generates a web preview URL for testing a WhatsApp Flow before publishing. Preview URLs expire in 30 days and can be shared with stakeholders for review.
309 |
# File 'sig/client.rbs', line 309
def get_whats_app_flow_preview: (
|
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service. On successful completion
the media file is retrieved from Meta and stored in the specified
Amazon S3 bucket. Use either destinationS3File or
destinationS3PresignedUrl for the destination. If both are used then
an InvalidParameterException is returned.
322 |
# File 'sig/client.rbs', line 322
def get_whats_app_message_media: (
|
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
342 |
# File 'sig/client.rbs', line 342
def get_whats_app_message_template: (
|
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
356 |
# File 'sig/client.rbs', line 356
def list_linked_whats_app_business_accounts: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
368 |
# File 'sig/client.rbs', line 368
def list_tags_for_resource: (
|
#list_whats_app_flow_assets(params = {}) ⇒ Types::ListWhatsAppFlowAssetsOutput
Lists the assets (Flow JSON definition) of a WhatsApp Flow with presigned download URLs. Download URLs are generated by Meta and expire after a short period.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
379 |
# File 'sig/client.rbs', line 379
def list_whats_app_flow_assets: (
|
#list_whats_app_flows(params = {}) ⇒ Types::ListWhatsAppFlowsOutput
Lists all WhatsApp Flows for a WhatsApp Business Account. Returns summary information including Flow ID, name, status, and categories.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
393 |
# File 'sig/client.rbs', line 393
def list_whats_app_flows: (
|
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
406 |
# File 'sig/client.rbs', line 406
def list_whats_app_message_templates: (
|
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta's template library for WhatsApp messaging.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
419 |
# File 'sig/client.rbs', line 419
def list_whats_app_template_library: (
|
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service. Only the specified
originationPhoneNumberId has the permissions to send the media file
when using SendWhatsAppMessage. You must use either
sourceS3File or sourceS3PresignedUrl for the source. If both or
neither are specified then an InvalidParameterException is returned.
432 |
# File 'sig/client.rbs', line 432
def post_whats_app_message_media: (
|
#publish_whats_app_flow(params = {}) ⇒ Struct
Publishes a WhatsApp Flow, making it available for use in template messages. The Flow must be in DRAFT status with valid Flow JSON that passes Meta's validation. This is an irreversible operation.
449 |
# File 'sig/client.rbs', line 449
def publish_whats_app_flow: (
|
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA). A WABA can only have one event destination at a time. All resources associated with the WABA use the same event destination.
459 |
# File 'sig/client.rbs', line 459
def put_whats_app_business_account_event_destinations: (
|
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message. For examples of sending a message using the Amazon Web Services CLI, see Sending messages in the Amazon Web Services End User Messaging Social User Guide .
475 |
# File 'sig/client.rbs', line 475
def send_whats_app_message: (
|
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource. When you specify an existing tag key, the value is overwritten with the new value.
487 |
# File 'sig/client.rbs', line 487
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
503 |
# File 'sig/client.rbs', line 503
def untag_resource: (
|
#update_whats_app_flow(params = {}) ⇒ Struct
Updates the metadata of a WhatsApp Flow, such as its name or categories. This does not update the Flow JSON definition. Use UpdateWhatsAppFlowAssets to update the Flow JSON.
513 |
# File 'sig/client.rbs', line 513
def update_whats_app_flow: (
|
#update_whats_app_flow_assets(params = {}) ⇒ Types::UpdateWhatsAppFlowAssetsOutput
Updates the Flow JSON definition (assets) of a WhatsApp Flow. Updating a published Flow's assets reverts it to DRAFT status, requiring re-publishing.
526 |
# File 'sig/client.rbs', line 526
def update_whats_app_flow_assets: (
|
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
537 |
# File 'sig/client.rbs', line 537
def update_whats_app_message_template: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1969 1970 1971 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1969 def waiter_names [] end |