Class: Aws::SocialMessaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SocialMessaging::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-socialmessaging/client.rb
Overview
An API client for SocialMessaging. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SocialMessaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
-
#create_whats_app_flow(params = {}) ⇒ Types::CreateWhatsAppFlowOutput
Creates a new WhatsApp Flow.
-
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
-
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta’s template library.
-
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
-
#delete_whats_app_flow(params = {}) ⇒ Struct
Deletes a WhatsApp Flow permanently.
-
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service.
-
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
-
#deprecate_whats_app_flow(params = {}) ⇒ Struct
Deprecates a published WhatsApp Flow, marking it as no longer recommended for use.
-
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
-
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
-
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
-
#get_whats_app_flow(params = {}) ⇒ Types::GetWhatsAppFlowOutput
Retrieves the metadata and status of a WhatsApp Flow, including validation errors, preview information, and health status.
-
#get_whats_app_flow_preview(params = {}) ⇒ Types::GetWhatsAppFlowPreviewOutput
Generates a web preview URL for testing a WhatsApp Flow before publishing.
-
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service.
-
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
-
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
-
#list_whats_app_flow_assets(params = {}) ⇒ Types::ListWhatsAppFlowAssetsOutput
Lists the assets (Flow JSON definition) of a WhatsApp Flow with presigned download URLs.
-
#list_whats_app_flows(params = {}) ⇒ Types::ListWhatsAppFlowsOutput
Lists all WhatsApp Flows for a WhatsApp Business Account.
-
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
-
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta’s template library for WhatsApp messaging.
-
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service.
-
#publish_whats_app_flow(params = {}) ⇒ Struct
Publishes a WhatsApp Flow, making it available for use in template messages.
-
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA).
-
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message.
-
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource.
-
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
-
#update_whats_app_flow(params = {}) ⇒ Struct
Updates the metadata of a WhatsApp Flow, such as its name or categories.
-
#update_whats_app_flow_assets(params = {}) ⇒ Types::UpdateWhatsAppFlowAssetsOutput
Updates the Flow JSON definition (assets) of a WhatsApp Flow.
-
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1976 1977 1978 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1976 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1979 1980 1981 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1979 def errors_module Errors end |
Instance Method Details
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
558 559 560 561 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 558 def associate_whats_app_business_account(params = {}, = {}) req = build_request(:associate_whats_app_business_account, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1949 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SocialMessaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-socialmessaging' context[:gem_version] = '1.27.0' Seahorse::Client::Request.new(handlers, context) end |
#create_whats_app_flow(params = {}) ⇒ Types::CreateWhatsAppFlowOutput
Creates a new WhatsApp Flow. Flows enable businesses to create rich, interactive forms and experiences that users can complete without leaving WhatsApp. The Flow is created in DRAFT status. If ‘publish` is set to `true` and a valid `flowJson` is provided, the Flow is published immediately.
618 619 620 621 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 618 def create_whats_app_flow(params = {}, = {}) req = build_request(:create_whats_app_flow, params) req.send_request() end |
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
<note markdown=“1”> Amazon Web Services End User Messaging Social does not store any WhatsApp message template content.
</note>
660 661 662 663 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 660 def (params = {}, = {}) req = build_request(:create_whats_app_message_template, params) req.send_request() end |
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta’s template library.
727 728 729 730 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 727 def (params = {}, = {}) req = build_request(:create_whats_app_message_template_from_library, params) req.send_request() end |
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
763 764 765 766 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 763 def (params = {}, = {}) req = build_request(:create_whats_app_message_template_media, params) req.send_request() end |
#delete_whats_app_flow(params = {}) ⇒ Struct
Deletes a WhatsApp Flow permanently. Only Flows in DRAFT status can be deleted. Published or deprecated Flows cannot be deleted.
790 791 792 793 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 790 def delete_whats_app_flow(params = {}, = {}) req = build_request(:delete_whats_app_flow, params) req.send_request() end |
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service. If the object is still in an Amazon S3 bucket you should delete it from there too.
835 836 837 838 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 835 def (params = {}, = {}) req = build_request(:delete_whats_app_message_media, params) req.send_request() end |
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
869 870 871 872 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 869 def (params = {}, = {}) req = build_request(:delete_whats_app_message_template, params) req.send_request() end |
#deprecate_whats_app_flow(params = {}) ⇒ Struct
Deprecates a published WhatsApp Flow, marking it as no longer recommended for use. The Flow must be in PUBLISHED status. This is an irreversible operation.
897 898 899 900 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 897 def deprecate_whats_app_flow(params = {}, = {}) req = build_request(:deprecate_whats_app_flow, params) req.send_request() end |
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
927 928 929 930 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 927 def disassociate_whats_app_business_account(params = {}, = {}) req = build_request(:disassociate_whats_app_business_account, params) req.send_request() end |
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
981 982 983 984 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 981 def get_linked_whats_app_business_account(params = {}, = {}) req = build_request(:get_linked_whats_app_business_account, params) req.send_request() end |
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
1026 1027 1028 1029 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1026 def get_linked_whats_app_business_account_phone_number(params = {}, = {}) req = build_request(:get_linked_whats_app_business_account_phone_number, params) req.send_request() end |
#get_whats_app_flow(params = {}) ⇒ Types::GetWhatsAppFlowOutput
Retrieves the metadata and status of a WhatsApp Flow, including validation errors, preview information, and health status.
1094 1095 1096 1097 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1094 def get_whats_app_flow(params = {}, = {}) req = build_request(:get_whats_app_flow, params) req.send_request() end |
#get_whats_app_flow_preview(params = {}) ⇒ Types::GetWhatsAppFlowPreviewOutput
Generates a web preview URL for testing a WhatsApp Flow before publishing. Preview URLs expire in 30 days and can be shared with stakeholders for review.
1137 1138 1139 1140 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1137 def get_whats_app_flow_preview(params = {}, = {}) req = build_request(:get_whats_app_flow_preview, params) req.send_request() end |
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service. On successful completion the media file is retrieved from Meta and stored in the specified Amazon S3 bucket. Use either ‘destinationS3File` or `destinationS3PresignedUrl` for the destination. If both are used then an `InvalidParameterException` is returned.
1202 1203 1204 1205 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1202 def (params = {}, = {}) req = build_request(:get_whats_app_message_media, params) req.send_request() end |
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
1246 1247 1248 1249 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1246 def (params = {}, = {}) req = build_request(:get_whats_app_message_template, params) req.send_request() end |
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1293 1294 1295 1296 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1293 def list_linked_whats_app_business_accounts(params = {}, = {}) req = build_request(:list_linked_whats_app_business_accounts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1327 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_whats_app_flow_assets(params = {}) ⇒ Types::ListWhatsAppFlowAssetsOutput
Lists the assets (Flow JSON definition) of a WhatsApp Flow with presigned download URLs. Download URLs are generated by Meta and expire after a short period.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1376 1377 1378 1379 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1376 def list_whats_app_flow_assets(params = {}, = {}) req = build_request(:list_whats_app_flow_assets, params) req.send_request() end |
#list_whats_app_flows(params = {}) ⇒ Types::ListWhatsAppFlowsOutput
Lists all WhatsApp Flows for a WhatsApp Business Account. Returns summary information including Flow ID, name, status, and categories.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1424 1425 1426 1427 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1424 def list_whats_app_flows(params = {}, = {}) req = build_request(:list_whats_app_flows, params) req.send_request() end |
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1471 1472 1473 1474 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1471 def (params = {}, = {}) req = build_request(:list_whats_app_message_templates, params) req.send_request() end |
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta’s template library for WhatsApp messaging.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1541 1542 1543 1544 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1541 def list_whats_app_template_library(params = {}, = {}) req = build_request(:list_whats_app_template_library, params) req.send_request() end |
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service. Only the specified ‘originationPhoneNumberId` has the permissions to send the media file when using [SendWhatsAppMessage]. You must use either `sourceS3File` or `sourceS3PresignedUrl` for the source. If both or neither are specified then an `InvalidParameterException` is returned.
[1]: docs.aws.amazon.com/social-messaging/latest/APIReference/API_SendWhatsAppMessage.html
1600 1601 1602 1603 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1600 def (params = {}, = {}) req = build_request(:post_whats_app_message_media, params) req.send_request() end |
#publish_whats_app_flow(params = {}) ⇒ Struct
Publishes a WhatsApp Flow, making it available for use in template messages. The Flow must be in DRAFT status with valid Flow JSON that passes Meta’s validation. This is an irreversible operation.
1628 1629 1630 1631 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1628 def publish_whats_app_flow(params = {}, = {}) req = build_request(:publish_whats_app_flow, params) req.send_request() end |
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA). A WABA can only have one event destination at a time. All resources associated with the WABA use the same event destination.
1670 1671 1672 1673 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1670 def put_whats_app_business_account_event_destinations(params = {}, = {}) req = build_request(:put_whats_app_business_account_event_destinations, params) req.send_request() end |
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message. For examples of sending a message using the Amazon Web Services CLI, see [Sending messages] in the Amazon Web Services End User Messaging Social User Guide .
[1]: docs.aws.amazon.com/social-messaging/latest/userguide/send-message.html
1733 1734 1735 1736 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1733 def (params = {}, = {}) req = build_request(:send_whats_app_message, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource. When you specify an existing tag key, the value is overwritten with the new value.
1772 1773 1774 1775 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1772 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
1804 1805 1806 1807 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1804 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_whats_app_flow(params = {}) ⇒ Struct
Updates the metadata of a WhatsApp Flow, such as its name or categories. This does not update the Flow JSON definition. Use
- UpdateWhatsAppFlowAssets][1
-
to update the Flow JSON.
[1]: docs.aws.amazon.com/social-messaging/latest/APIReference/API_UpdateWhatsAppFlowAssets.html
1844 1845 1846 1847 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1844 def update_whats_app_flow(params = {}, = {}) req = build_request(:update_whats_app_flow, params) req.send_request() end |
#update_whats_app_flow_assets(params = {}) ⇒ Types::UpdateWhatsAppFlowAssetsOutput
Updates the Flow JSON definition (assets) of a WhatsApp Flow. Updating a published Flow’s assets reverts it to DRAFT status, requiring re-publishing.
1883 1884 1885 1886 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1883 def update_whats_app_flow_assets(params = {}, = {}) req = build_request(:update_whats_app_flow_assets, params) req.send_request() end |
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
1940 1941 1942 1943 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1940 def (params = {}, = {}) req = build_request(:update_whats_app_message_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1969 1970 1971 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1969 def waiter_names [] end |