Class: Aws::SocialMessaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SocialMessaging::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-socialmessaging/client.rb
Overview
An API client for SocialMessaging. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SocialMessaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
-
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
-
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta’s template library.
-
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
-
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service.
-
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
-
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
-
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
-
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
-
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service.
-
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
-
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
-
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
-
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta’s template library for WhatsApp messaging.
-
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service.
-
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA).
-
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message.
-
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource.
-
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
-
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1546 1547 1548 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1546 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1549 1550 1551 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1549 def errors_module Errors end |
Instance Method Details
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
558 559 560 561 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 558 def associate_whats_app_business_account(params = {}, = {}) req = build_request(:associate_whats_app_business_account, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1519 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SocialMessaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-socialmessaging' context[:gem_version] = '1.25.0' Seahorse::Client::Request.new(handlers, context) end |
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
<note markdown=“1”> Amazon Web Services End User Messaging Social does not store any WhatsApp message template content.
</note>
600 601 602 603 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 600 def (params = {}, = {}) req = build_request(:create_whats_app_message_template, params) req.send_request() end |
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta’s template library.
667 668 669 670 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 667 def (params = {}, = {}) req = build_request(:create_whats_app_message_template_from_library, params) req.send_request() end |
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
703 704 705 706 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 703 def (params = {}, = {}) req = build_request(:create_whats_app_message_template_media, params) req.send_request() end |
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service. If the object is still in an Amazon S3 bucket you should delete it from there too.
748 749 750 751 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 748 def (params = {}, = {}) req = build_request(:delete_whats_app_message_media, params) req.send_request() end |
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
782 783 784 785 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 782 def (params = {}, = {}) req = build_request(:delete_whats_app_message_template, params) req.send_request() end |
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
812 813 814 815 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 812 def disassociate_whats_app_business_account(params = {}, = {}) req = build_request(:disassociate_whats_app_business_account, params) req.send_request() end |
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
866 867 868 869 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 866 def get_linked_whats_app_business_account(params = {}, = {}) req = build_request(:get_linked_whats_app_business_account, params) req.send_request() end |
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
911 912 913 914 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 911 def get_linked_whats_app_business_account_phone_number(params = {}, = {}) req = build_request(:get_linked_whats_app_business_account_phone_number, params) req.send_request() end |
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service. On successful completion the media file is retrieved from Meta and stored in the specified Amazon S3 bucket. Use either ‘destinationS3File` or `destinationS3PresignedUrl` for the destination. If both are used then an `InvalidParameterException` is returned.
976 977 978 979 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 976 def (params = {}, = {}) req = build_request(:get_whats_app_message_media, params) req.send_request() end |
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
1020 1021 1022 1023 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1020 def (params = {}, = {}) req = build_request(:get_whats_app_message_template, params) req.send_request() end |
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1067 1068 1069 1070 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1067 def list_linked_whats_app_business_accounts(params = {}, = {}) req = build_request(:list_linked_whats_app_business_accounts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
1101 1102 1103 1104 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1101 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1148 1149 1150 1151 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1148 def (params = {}, = {}) req = build_request(:list_whats_app_message_templates, params) req.send_request() end |
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta’s template library for WhatsApp messaging.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1218 1219 1220 1221 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1218 def list_whats_app_template_library(params = {}, = {}) req = build_request(:list_whats_app_template_library, params) req.send_request() end |
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service. Only the specified ‘originationPhoneNumberId` has the permissions to send the media file when using [SendWhatsAppMessage]. You must use either `sourceS3File` or `sourceS3PresignedUrl` for the source. If both or neither are specified then an `InvalidParameterException` is returned.
[1]: docs.aws.amazon.com/social-messaging/latest/APIReference/API_SendWhatsAppMessage.html
1277 1278 1279 1280 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1277 def (params = {}, = {}) req = build_request(:post_whats_app_message_media, params) req.send_request() end |
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA). A WABA can only have one event destination at a time. All resources associated with the WABA use the same event destination.
1319 1320 1321 1322 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1319 def put_whats_app_business_account_event_destinations(params = {}, = {}) req = build_request(:put_whats_app_business_account_event_destinations, params) req.send_request() end |
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message. For examples of sending a message using the Amazon Web Services CLI, see [Sending messages] in the Amazon Web Services End User Messaging Social User Guide .
[1]: docs.aws.amazon.com/social-messaging/latest/userguide/send-message.html
1382 1383 1384 1385 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1382 def (params = {}, = {}) req = build_request(:send_whats_app_message, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource. When you specify an existing tag key, the value is overwritten with the new value.
1421 1422 1423 1424 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1421 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
1453 1454 1455 1456 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1453 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
1510 1511 1512 1513 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1510 def (params = {}, = {}) req = build_request(:update_whats_app_message_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1539 1540 1541 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1539 def waiter_names [] end |