Class: Aws::SocialMessaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SocialMessaging::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-socialmessaging/client.rb
Overview
An API client for SocialMessaging. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SocialMessaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
-
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
-
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta’s template library.
-
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
-
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service.
-
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
-
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
-
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
-
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
-
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service.
-
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
-
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
-
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
-
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta’s template library for WhatsApp messaging.
-
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service.
-
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA).
-
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message.
-
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource.
-
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
-
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1548 1549 1550 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1548 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1551 1552 1553 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1551 def errors_module Errors end |
Instance Method Details
#associate_whats_app_business_account(params = {}) ⇒ Types::AssociateWhatsAppBusinessAccountOutput
This is only used through the Amazon Web Services console during sign-up to associate your WhatsApp Business Account to your Amazon Web Services account.
560 561 562 563 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 560 def associate_whats_app_business_account(params = {}, = {}) req = build_request(:associate_whats_app_business_account, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1521 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SocialMessaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-socialmessaging' context[:gem_version] = '1.24.0' Seahorse::Client::Request.new(handlers, context) end |
#create_whats_app_message_template(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateOutput
Creates a new WhatsApp message template from a custom definition.
<note markdown=“1”> Amazon Web Services End User Messaging Social does not store any WhatsApp message template content.
</note>
602 603 604 605 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 602 def (params = {}, = {}) req = build_request(:create_whats_app_message_template, params) req.send_request() end |
#create_whats_app_message_template_from_library(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateFromLibraryOutput
Creates a new WhatsApp message template using a template from Meta’s template library.
669 670 671 672 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 669 def (params = {}, = {}) req = build_request(:create_whats_app_message_template_from_library, params) req.send_request() end |
#create_whats_app_message_template_media(params = {}) ⇒ Types::CreateWhatsAppMessageTemplateMediaOutput
Uploads media for use in a WhatsApp message template.
705 706 707 708 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 705 def (params = {}, = {}) req = build_request(:create_whats_app_message_template_media, params) req.send_request() end |
#delete_whats_app_message_media(params = {}) ⇒ Types::DeleteWhatsAppMessageMediaOutput
Delete a media object from the WhatsApp service. If the object is still in an Amazon S3 bucket you should delete it from there too.
750 751 752 753 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 750 def (params = {}, = {}) req = build_request(:delete_whats_app_message_media, params) req.send_request() end |
#delete_whats_app_message_template(params = {}) ⇒ Struct
Deletes a WhatsApp message template.
784 785 786 787 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 784 def (params = {}, = {}) req = build_request(:delete_whats_app_message_template, params) req.send_request() end |
#disassociate_whats_app_business_account(params = {}) ⇒ Struct
Disassociate a WhatsApp Business Account (WABA) from your Amazon Web Services account.
814 815 816 817 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 814 def disassociate_whats_app_business_account(params = {}, = {}) req = build_request(:disassociate_whats_app_business_account, params) req.send_request() end |
#get_linked_whats_app_business_account(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountOutput
Get the details of your linked WhatsApp Business Account.
868 869 870 871 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 868 def get_linked_whats_app_business_account(params = {}, = {}) req = build_request(:get_linked_whats_app_business_account, params) req.send_request() end |
#get_linked_whats_app_business_account_phone_number(params = {}) ⇒ Types::GetLinkedWhatsAppBusinessAccountPhoneNumberOutput
Retrieve the WABA account id and phone number details of a WhatsApp business account phone number.
913 914 915 916 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 913 def get_linked_whats_app_business_account_phone_number(params = {}, = {}) req = build_request(:get_linked_whats_app_business_account_phone_number, params) req.send_request() end |
#get_whats_app_message_media(params = {}) ⇒ Types::GetWhatsAppMessageMediaOutput
Get a media file from the WhatsApp service. On successful completion the media file is retrieved from Meta and stored in the specified Amazon S3 bucket. Use either ‘destinationS3File` or `destinationS3PresignedUrl` for the destination. If both are used then an `InvalidParameterException` is returned.
978 979 980 981 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 978 def (params = {}, = {}) req = build_request(:get_whats_app_message_media, params) req.send_request() end |
#get_whats_app_message_template(params = {}) ⇒ Types::GetWhatsAppMessageTemplateOutput
Retrieves a specific WhatsApp message template.
1022 1023 1024 1025 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1022 def (params = {}, = {}) req = build_request(:get_whats_app_message_template, params) req.send_request() end |
#list_linked_whats_app_business_accounts(params = {}) ⇒ Types::ListLinkedWhatsAppBusinessAccountsOutput
List all WhatsApp Business Accounts linked to your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1069 1070 1071 1072 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1069 def list_linked_whats_app_business_accounts(params = {}, = {}) req = build_request(:list_linked_whats_app_business_accounts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List all tags associated with a resource, such as a phone number or WABA.
1103 1104 1105 1106 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1103 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_whats_app_message_templates(params = {}) ⇒ Types::ListWhatsAppMessageTemplatesOutput
Lists WhatsApp message templates for a specific WhatsApp Business Account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1150 1151 1152 1153 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1150 def (params = {}, = {}) req = build_request(:list_whats_app_message_templates, params) req.send_request() end |
#list_whats_app_template_library(params = {}) ⇒ Types::ListWhatsAppTemplateLibraryOutput
Lists templates available in Meta’s template library for WhatsApp messaging.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1220 1221 1222 1223 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1220 def list_whats_app_template_library(params = {}, = {}) req = build_request(:list_whats_app_template_library, params) req.send_request() end |
#post_whats_app_message_media(params = {}) ⇒ Types::PostWhatsAppMessageMediaOutput
Upload a media file to the WhatsApp service. Only the specified ‘originationPhoneNumberId` has the permissions to send the media file when using [SendWhatsAppMessage]. You must use either `sourceS3File` or `sourceS3PresignedUrl` for the source. If both or neither are specified then an `InvalidParameterException` is returned.
[1]: docs.aws.amazon.com/social-messaging/latest/APIReference/API_SendWhatsAppMessage.html
1279 1280 1281 1282 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1279 def (params = {}, = {}) req = build_request(:post_whats_app_message_media, params) req.send_request() end |
#put_whats_app_business_account_event_destinations(params = {}) ⇒ Struct
Add an event destination to log event data from WhatsApp for a WhatsApp Business Account (WABA). A WABA can only have one event destination at a time. All resources associated with the WABA use the same event destination.
1321 1322 1323 1324 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1321 def put_whats_app_business_account_event_destinations(params = {}, = {}) req = build_request(:put_whats_app_business_account_event_destinations, params) req.send_request() end |
#send_whats_app_message(params = {}) ⇒ Types::SendWhatsAppMessageOutput
Send a WhatsApp message. For examples of sending a message using the Amazon Web Services CLI, see [Sending messages] in the Amazon Web Services End User Messaging Social User Guide .
[1]: docs.aws.amazon.com/social-messaging/latest/userguide/send-message.html
1384 1385 1386 1387 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1384 def (params = {}, = {}) req = build_request(:send_whats_app_message, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Adds or overwrites only the specified tags for the specified resource. When you specify an existing tag key, the value is overwritten with the new value.
1423 1424 1425 1426 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1423 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes the specified tags from a resource.
1455 1456 1457 1458 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1455 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_whats_app_message_template(params = {}) ⇒ Struct
Updates an existing WhatsApp message template.
1512 1513 1514 1515 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1512 def (params = {}, = {}) req = build_request(:update_whats_app_message_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1541 1542 1543 |
# File 'lib/aws-sdk-socialmessaging/client.rb', line 1541 def waiter_names [] end |