Class: Aws::SocialMessaging::Types::CreateWhatsAppFlowInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::CreateWhatsAppFlowInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#categories ⇒ Array<String>
The categories that classify the business purpose of the Flow.
-
#clone_flow_id ⇒ String
The ID of an existing Flow within the same WhatsApp Business Account to clone.
-
#flow_json ⇒ String
The Flow JSON definition that describes the screens, components, and logic of the Flow.
-
#flow_name ⇒ String
The name of the Flow.
-
#id ⇒ String
The ID of the WhatsApp Business Account to associate with this Flow.
-
#publish ⇒ Boolean
Set to ‘true` to publish the Flow immediately after creation.
Instance Attribute Details
#categories ⇒ Array<String>
The categories that classify the business purpose of the Flow. At least one category is required.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111 class CreateWhatsAppFlowInput < Struct.new( :id, :flow_name, :categories, :flow_json, :publish, :clone_flow_id) SENSITIVE = [] include Aws::Structure end |
#clone_flow_id ⇒ String
The ID of an existing Flow within the same WhatsApp Business Account to clone.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111 class CreateWhatsAppFlowInput < Struct.new( :id, :flow_name, :categories, :flow_json, :publish, :clone_flow_id) SENSITIVE = [] include Aws::Structure end |
#flow_json ⇒ String
The Flow JSON definition that describes the screens, components, and logic of the Flow. Maximum size is 10 MB.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111 class CreateWhatsAppFlowInput < Struct.new( :id, :flow_name, :categories, :flow_json, :publish, :clone_flow_id) SENSITIVE = [] include Aws::Structure end |
#flow_name ⇒ String
The name of the Flow. Must be unique within the WhatsApp Business Account.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111 class CreateWhatsAppFlowInput < Struct.new( :id, :flow_name, :categories, :flow_json, :publish, :clone_flow_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the WhatsApp Business Account to associate with this Flow.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111 class CreateWhatsAppFlowInput < Struct.new( :id, :flow_name, :categories, :flow_json, :publish, :clone_flow_id) SENSITIVE = [] include Aws::Structure end |
#publish ⇒ Boolean
Set to ‘true` to publish the Flow immediately after creation. Requires a valid `flowJson` that passes Meta’s validation.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 111 class CreateWhatsAppFlowInput < Struct.new( :id, :flow_name, :categories, :flow_json, :publish, :clone_flow_id) SENSITIVE = [] include Aws::Structure end |