Class: Aws::SocialMessaging::Types::MetaLibraryTemplateDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::MetaLibraryTemplateDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Defines the complete structure and content of a template in Meta’s library.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#template_body ⇒ String
The body text of the template.
-
#template_body_example_params ⇒ Array<String>
Example parameter values for the template body, used to demonstrate how dynamic content appears in the template.
-
#template_buttons ⇒ Array<Types::LibraryTemplateButtonList>
The buttons included in the template.
-
#template_category ⇒ String
The category of the template (for example, UTILITY or MARKETING).
-
#template_header ⇒ String
The header text of the template.
-
#template_id ⇒ String
The ID of the template in Meta’s library.
-
#template_industry ⇒ Array<String>
The industries the template is designed for.
-
#template_language ⇒ String
The language code for the template (for example, en_US).
-
#template_name ⇒ String
The name of the template.
-
#template_topic ⇒ String
The topic or subject matter of the template.
-
#template_use_case ⇒ String
The intended use case for the template.
Instance Attribute Details
#template_body ⇒ String
The body text of the template.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_body_example_params ⇒ Array<String>
Example parameter values for the template body, used to demonstrate how dynamic content appears in the template.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_buttons ⇒ Array<Types::LibraryTemplateButtonList>
The buttons included in the template.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_category ⇒ String
The category of the template (for example, UTILITY or MARKETING).
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_header ⇒ String
The header text of the template.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The ID of the template in Meta’s library.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_industry ⇒ Array<String>
The industries the template is designed for.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_language ⇒ String
The language code for the template (for example, en_US).
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the template.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_topic ⇒ String
The topic or subject matter of the template.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |
#template_use_case ⇒ String
The intended use case for the template.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1517 class MetaLibraryTemplateDefinition < Struct.new( :template_name, :template_language, :template_category, :template_topic, :template_use_case, :template_industry, :template_header, :template_body, :template_buttons, :template_id, :template_body_example_params) SENSITIVE = [] include Aws::Structure end |