Class: Aws::SocialMessaging::Types::S3File
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::S3File
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Contains information for the S3 bucket that contains media files.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The bucket name.
-
#key ⇒ String
The S3 key prefix that defines the storage location of your media files.
Instance Attribute Details
#bucket_name ⇒ String
The bucket name.
1133 1134 1135 1136 1137 1138 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1133 class S3File < Struct.new( :bucket_name, :key) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The S3 key prefix that defines the storage location of your media files. The prefix works like a folder path in S3, and is combined with the WhatsApp mediaId to create the final file path.
For example, if a media file’s WhatsApp mediaId is ‘123.ogg`, and the key is `audio/example.ogg`, the final file path is `audio/example.ogg123.ogg`.
For the same mediaId, a key of ‘audio/` results in the file path `audio/123.ogg`.
1133 1134 1135 1136 1137 1138 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1133 class S3File < Struct.new( :bucket_name, :key) SENSITIVE = [] include Aws::Structure end |