Class: Aws::SocialMessaging::Types::UpdateWhatsAppMessageTemplateInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-socialmessaging/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

When true, disables click tracking for call-to-action URL buttons in the template.

Returns:

  • (Boolean)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the WhatsApp Business Account associated with this template.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end

#meta_template_idString

The numeric ID of the template assigned by Meta.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_formatString

The format specification for parameters in the template, this can be either ‘named’ or ‘positional’.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end

#template_categoryString

The new category for the template (for example, UTILITY or MARKETING).

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end

#template_componentsString

The updated components of the template as a JSON blob (maximum 3000 characters).

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end

#template_language_codeString

The language code of the message template (for example, ‘en` or `en_US`). Use together with `templateName` as an alternative to `metaTemplateId` to identify a template.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the message template. Use together with ‘templateLanguageCode` as an alternative to `metaTemplateId` to identify a template.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401

class UpdateWhatsAppMessageTemplateInput < Struct.new(
  :id,
  :meta_template_id,
  :template_name,
  :template_language_code,
  :parameter_format,
  :template_category,
  :template_components,
  :cta_url_link_tracking_opted_out)
  SENSITIVE = []
  include Aws::Structure
end