Class: Aws::SocialMessaging::Types::UpdateWhatsAppMessageTemplateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SocialMessaging::Types::UpdateWhatsAppMessageTemplateInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-socialmessaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cta_url_link_tracking_opted_out ⇒ Boolean
When true, disables click tracking for call-to-action URL buttons in the template.
-
#id ⇒ String
The ID of the WhatsApp Business Account associated with this template.
-
#meta_template_id ⇒ String
The numeric ID of the template assigned by Meta.
-
#parameter_format ⇒ String
The format specification for parameters in the template, this can be either ‘named’ or ‘positional’.
-
#template_category ⇒ String
The new category for the template (for example, UTILITY or MARKETING).
-
#template_components ⇒ String
The updated components of the template as a JSON blob (maximum 3000 characters).
-
#template_language_code ⇒ String
The language code of the message template (for example, ‘en` or `en_US`).
-
#template_name ⇒ String
The name of the message template.
Instance Attribute Details
#cta_url_link_tracking_opted_out ⇒ Boolean
When true, disables click tracking for call-to-action URL buttons in the template.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the WhatsApp Business Account associated with this template.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |
#meta_template_id ⇒ String
The numeric ID of the template assigned by Meta.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |
#parameter_format ⇒ String
The format specification for parameters in the template, this can be either ‘named’ or ‘positional’.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |
#template_category ⇒ String
The new category for the template (for example, UTILITY or MARKETING).
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |
#template_components ⇒ String
The updated components of the template as a JSON blob (maximum 3000 characters).
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |
#template_language_code ⇒ String
The language code of the message template (for example, ‘en` or `en_US`). Use together with `templateName` as an alternative to `metaTemplateId` to identify a template.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the message template. Use together with ‘templateLanguageCode` as an alternative to `metaTemplateId` to identify a template.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-socialmessaging/types.rb', line 1401 class UpdateWhatsAppMessageTemplateInput < Struct.new( :id, :meta_template_id, :template_name, :template_language_code, :parameter_format, :template_category, :template_components, :cta_url_link_tracking_opted_out) SENSITIVE = [] include Aws::Structure end |